@@ -202,8 +202,15 @@ class TimeCategories(object):
 		self._today = newToday
 		for item in self._timeItems:
 			item.removeRows(0, item.rowCount())
-		self._timeItems[self._NOW_SECTION].setText(self._today.strftime("%X"))
-		self._timeItems[self._TODAY_SECTION].setText(self._today.strftime("%x"))
+		try:
+			hour = self._today.strftime("%X")
+			day = self._today.strftime("%x")
+		except ValueError:
+			_moduleLogger.exception("Can't format times")
+			hour = "Now"
+			day = "Today"
+		self._timeItems[self._NOW_SECTION].setText(hour)
+		self._timeItems[self._TODAY_SECTION].setText(day)
 
 	def add_row(self, rowDate, row):
 		elapsedTime = self._today - rowDate
@@ -357,7 +364,7 @@ class History(object):
 	def _on_row_activated(self, index):
 		with qui_utils.notify_error(self._errorLog):
 			timeIndex = index.parent()
-			assert timeIndex.isValid()
+			assert timeIndex.isValid(), "Invalid row"
 			timeRow = timeIndex.row()
 			row = index.row()
 			detailsItem = self._categoryManager.get_item(timeRow, row, self.DETAILS_IDX)
@@ -579,7 +586,7 @@ class Messages(object):
 	def _on_row_activated(self, index):
 		with qui_utils.notify_error(self._errorLog):
 			timeIndex = index.parent()
-			assert timeIndex.isValid()
+			assert timeIndex.isValid(), "Invalid row"
 			timeRow = timeIndex.row()
 			row = index.row()
 			item = self._categoryManager.get_item(timeRow, row, 0)
@@ -776,7 +783,7 @@ class Contacts(object):
 	def _on_row_activated(self, index):
 		with qui_utils.notify_error(self._errorLog):
 			letterIndex = index.parent()
-			assert letterIndex.isValid()
+			assert letterIndex.isValid(), "Invalid row"
 			letterRow = letterIndex.row()
 			letter = list(self._prefixes())[letterRow]
 			letterItem = self._alphaItem[letter]
